@@ -1,46 +1,41 @@
 #! /usr/bin/env python
 import os, sys, shutil, re, yaml
 from optparse import OptionParser
+
 import kickstarter
 
-
 parser = OptionParser()
-parser.add_option("-t", "--template", dest="template", help="specify project template", default="default")
-parser.add_option("-a", "--add-template", dest="new_template", help="add a new template directory") 
-parser.add_option("-d", "--default-template", dest="default_template", help="set default template") 
+parser.add_option("-t", "--template", dest="template", help="default project template", default="default")
+parser.add_option("-a", "--add-template", dest="add", help="install new template")
+parser.add_option("-r", "--remove-template", dest="remove", help="remove a template")
+parser.add_option("-d", "--default", dest="default_template", help="set default template")
 (options, args) = parser.parse_args()
 
+template_dir = os.path.join(kickstarter.__path__[0], 'templates', options.template)
+
+
+def set_default():
+    templates_dir = os.path.join(kickstarter.__path__[0], 'templates')
+    shutil.rmtree('%s/default' % templates_dir)
+    shutil.copytree('%s/%s' % (templates_dir, options.default_template), '%s/%s' % (templates_dir, 'default'))
+    shutil.copytree('%s/default/%s' % (templates_dir, options.default_template), '%s/default/default' % templates_dir)
+    shutil.rmtree('%s/default/%s' % (templates_dir, options.default_template))
+
 
 def create_template():
     templates_dir = os.path.join(kickstarter.__path__[0], 'templates')
-
-    if os.path.exists('%s/%s' % (templates_dir, options.new_template)):
-        override = raw_input('%s already exists. Override? [y/n]: ' % options.new_template)
-
-        if override == 'y':
-            shutil.rmtree('%s/%s' % (templates_dir, options.new_template))
-            shutil.copytree(options.new_template, '%s/%s' % (templates_dir, os.path.dirname(options.new_template)))
-        else:
-            print 'Aborting'
-    else:
-        shutil.copytree(options.new_template, '%s/%s' % (templates_dir, os.path.dirname(options.new_template)))
+    shutil.copytree(options.add, '%s/%s' % (templates_dir, options.add))
 
 
-def set_default_template():
+def remove_template():
     templates_dir = os.path.join(kickstarter.__path__[0], 'templates')
-    shutil.rmtree('%s/default' % templates_dir)
-    shutil.copytree('%s/%s' % (templates_dir, options.default_template), '%s/%s' % (templates_dir, 'default'))
-    shutil.copytree('%s/%s/%s' % (templates_dir, 'default', options.default_template), '%s/%s/%s' % (templates_dir, 'default', 'default')) 
-    shutil.rmtree('%s/%s/%s' % (templates_dir, 'default', options.default_template))
+    shutil.rmtree('%s/%s' % (templates_dir, options.remove))
 
 
-def create_project():
-    name = args[0]
-    template_dir = os.path.join(kickstarter.__path__[0], 'templates', options.template)
-
+def create_project(name, template):
     config = {}
-    config['project_module'] = re.sub('\-', '_', args[0])
     config['project'] = re.sub('\-', '_', args[0])
+    config['project_module'] = re.sub('\-', '_', args[0])
     config['project_name'] = args[0]
     config['project_root'] = '%s/%s' % (os.getcwd(), args[0])
 
@@ -48,9 +43,9 @@ def create_project():
         key = match.groups(1)[0].lower()
         return config[key]
 
-    def config_prompt():
-        if os.path.exists('%s/%s' % (template_dir, 'config.yaml')):
-            c = open('%s/%s' % (template_dir, 'config.yaml'), 'r')
+    def config_prompt(template):
+        if os.path.exists('%s/%s' % (template, 'config.yaml')):
+            c = open('%s/%s' % (template, 'config.yaml'), 'r')
             parsed_conf = re.sub('{{\s*(\w+)\s*}}', args[0], c.read())
             c.close()
 
@@ -61,11 +56,13 @@ def create_project():
                 config[option.lower()] = value if value != '' else default
 
     def copy_template():
-        config_prompt()
-        shutil.copytree(template_dir, name)
-        shutil.copytree('%s/%s' % (name, options.template), '%s/%s' % (name, config['project_module'])) 
+        config_prompt(template)
+        shutil.copytree(template, name)
+        shutil.copytree('%s/%s' % (name, options.template), '%s/%s' % (name, config['project'])) 
         shutil.rmtree('%s/%s' % (name, options.template))
-        os.remove('%s/%s' % (name, 'config.yaml'))
+
+        if os.path.exists('%s/%s' % (name, 'config.yaml')):
+            os.remove('%s/%s' % (name, 'config.yaml'))
 
         for dirname, dirnames, files in os.walk(name):
             for filename in files:
@@ -91,10 +88,11 @@ def create_project():
     else:
         copy_template()
 
-
-if options.new_template:
+if options.add:
     create_template()
+elif options.remove:
+    remove_template()
 elif options.default_template:
-    set_default_template()
+    set_default()
 else:
-    create_project()
+    create_project(args[0], template_dir)
